@@ -61,7 +61,7 @@ cite_packages <- function(session = NULL, include_R = TRUE, ...) {
     x <- report_table(session, include_R = include_R)
   }
 
-  x <- x$Reference[order(x$Reference)] # Extract the references
+  x <- sort(x$Reference, na.last = TRUE) # Extract the references
 
   as.report_parameters(x, ...)
 }
@@ -97,7 +97,7 @@ report_system <- function(session = NULL) {
     "; ",
     citation,
     ") on ",
-    text_remove(session$running, " \\(build.*")
+    datawizard::text_remove(session$running, " \\(build.*")
   )
 
   as.report_text(text, summary = short)
@@ -112,13 +112,13 @@ report_table.sessionInfo <- function(x, include_R = TRUE, ...) {
   pkgs <- x$otherPkgs
 
   if (isTRUE(include_R)) {
-    citations <- c(clean_citation(utils::citation("base")))
-    versions <- c(paste0(x$R.version$major, ".", x$R.version$minor))
-    names <- c("R")
+    citations <- clean_citation(utils::citation("base"))
+    versions <- paste0(x$R.version$major, ".", x$R.version$minor)
+    names <- "R"
   } else {
-    citations <- c()
-    versions <- c()
-    names <- c()
+    citations <- NULL
+    versions <- NULL
+    names <- NULL
   }
 
 
@@ -146,7 +146,6 @@ report_table.sessionInfo <- function(x, include_R = TRUE, ...) {
 
 #' @export
 report_parameters.sessionInfo <- function(x, table = NULL, include_R = TRUE, ...) {
-
   # Get table
   if (is.null(table)) {
     x <- report_table(x)
@@ -191,7 +190,7 @@ report_text.sessionInfo <- function(x, table = NULL, ...) {
   text <- paste0(
     sys,
     ", using the packages ",
-    text_concatenate(params),
+    datawizard::text_concatenate(params),
     ".\n\nReferences\n----------\n",
     as.character(cite_packages(x, table = table, ...))
   )
@@ -199,7 +198,7 @@ report_text.sessionInfo <- function(x, table = NULL, ...) {
   short <- paste0(
     summary(sys),
     ", using the packages ",
-    text_concatenate(summary(params)),
+    datawizard::text_concatenate(summary(params)),
     "."
   )
 
